aboutsummaryrefslogtreecommitdiff
path: root/src/kernel/chainparams.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/chainparams.h')
-rw-r--r--src/kernel/chainparams.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/kernel/chainparams.h b/src/kernel/chainparams.h
index 05ebd07ec7..c4584600fd 100644
--- a/src/kernel/chainparams.h
+++ b/src/kernel/chainparams.h
@@ -50,11 +50,11 @@ struct AssumeutxoData {
//! The expected hash of the deserialized UTXO set.
AssumeutxoHash hash_serialized;
//! Used to populate the nChainTx value, which is used during BlockManager::LoadBlockIndex().
//!
//! We need to hardcode the value here because this is computed cumulatively using block data,
//! which we do not necessarily have at the time of snapshot load.
- unsigned int nChainTx;
+ uint64_t m_chain_tx_count;
//! The hash of the base block for this snapshot. Used to refer to assumeutxo data
//! prior to having a loaded blockindex.
@@ -69,7 +69,7 @@ struct AssumeutxoData {
*/
struct ChainTxData {
int64_t nTime; //!< UNIX timestamp of last known number of transactions
- int64_t nTxCount; //!< total number of transactions between genesis and that timestamp
+ uint64_t tx_count; //!< total number of transactions between genesis and that timestamp
double dTxRate; //!< estimated number of transactions per second after that timestamp
};
@@ -161,9 +161,10 @@ public:
static std::unique_ptr<const CChainParams> SigNet(const SigNetOptions& options);
static std::unique_ptr<const CChainParams> Main();
static std::unique_ptr<const CChainParams> TestNet();
+ static std::unique_ptr<const CChainParams> TestNet4();
protected:
- CChainParams() {}
+ CChainParams() = default;
Consensus::Params consensus;
MessageStartChars pchMessageStart;
@@ -50,11 +50,11 @@ struct AssumeutxoData {
//! The expected hash of the deserialized UTXO set.
AssumeutxoHash hash_serialized;
- //! Used to populate the nChainTx value, which is used during BlockManager::LoadBlockIndex().
+ //! Used to populate the m_chain_tx_count value, which is used during BlockManager::LoadBlockIndex().
//!
//! We need to hardcode the value here because this is computed cumulatively using block data,